bayespy.inference.vmp.nodes.gamma.GammaDistribution.plates_to_parent
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gamma

.. automethod:: GammaDistribution.plates_to_parent